Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(47)

Unified Diff: webkit/fileapi/file_system_mount_point_provider.h

Issue 10447083: Rename webkit_blob::FileReader to FileStreamReader. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: merge master branch. Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/fileapi/file_system_file_stream_reader.cc ('k') | webkit/fileapi/file_system_url_request_job.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/fileapi/file_system_mount_point_provider.h
diff --git a/webkit/fileapi/file_system_mount_point_provider.h b/webkit/fileapi/file_system_mount_point_provider.h
index e47681b5d121c55719b54d61e626c95e2b5975e0..61617243de10069031de744a616535c7d1397df3 100644
--- a/webkit/fileapi/file_system_mount_point_provider.h
+++ b/webkit/fileapi/file_system_mount_point_provider.h
@@ -17,7 +17,7 @@
class GURL;
namespace webkit_blob {
-class FileReader;
+class FileStreamReader;
}
namespace fileapi {
@@ -92,12 +92,12 @@ class FILEAPI_EXPORT FileSystemMountPointProvider {
const FilePath& virtual_path,
FileSystemContext* context) const = 0;
// Creates a new file reader for a given filesystem URL |url| with a offset
// |offset|.
// The returned object must be owned and managed by the caller.
// This method itself does *not* check if the given path exists and is a
// regular file.
- virtual webkit_blob::FileReader* CreateFileReader(
+ virtual webkit_blob::FileStreamReader* CreateFileStreamReader(
const GURL& url,
int64 offset,
FileSystemContext* context) const = 0;
@@ -92,12 +92,12 @@ class FILEAPI_EXPORT FileSystemMountPointProvider {
const FilePath& virtual_path,
FileSystemContext* context) const = 0;
- // Creates a new file reader for a given filesystem URL |url| with a offset
- // |offset|.
+ // Creates a new file stream reader for a given filesystem URL |url| with an
+ // offset |offset|.
// The returned object must be owned and managed by the caller.
// This method itself does *not* check if the given path exists and is a
« no previous file with comments | « webkit/fileapi/file_system_file_stream_reader.cc ('k') | webkit/fileapi/file_system_url_request_job.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698